---
title: Gramex init
prefix: Init
...

Starting `Gramex v1.26`, all projects are required to use `gramex init`. This will setup the necessary project linting files and default files.

## Gramex init usage

Run `gramex init` on your preferred terminal (command prompt/cmder/terminal etc.)

List of files generated are below. (Click on the file for help.)

- [`.editorconfig`](http://editorconfig.org/)
- [`.eslintrc.js`](https://eslint.org/docs/user-guide/configuring)
- [`.flake8`](http://flake8.pycqa.org/en/latest/user/configuration.html)
- [`.gitignore`](https://git-scm.com/docs/gitignore)
- [`.gitlab-ci.yml`](https://docs.gitlab.com/ce/ci/yaml/)
- [`.htmllintrc`](https://github.com/htmllint/htmllint)

In addition, it generates a simple boilerplate for

- `gramex.yaml`
- `index.html`
- `README.md`

## Gramex init tracker

The status of `gramex init` adoption in projects is tracked on [codogram](https://learn.gramener.com/codogram/#projects/) (init column).
